==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KryteriumOceny.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypKryteriumOceny;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class KryteriumOceny extends GenericDPSObject {
    /**
     * KRYTERIUM_OCENY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * KRYTERIUM_OCENY.TEKST
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tekst;

    /**
     * KRYTERIUM_OCENY.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypKryteriumOceny typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KRYTERIUM_OCENY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KRYTERIUM_OCENY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KRYTERIUM_OCENY.TEKST
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * KRYTERIUM_OCENY.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @return KRYTERIUM_OCENY.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypKryteriumOceny getTyp() {
        return typ;
    }

    /**
     * KRYTERIUM_OCENY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypKryteriumOceny typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KryteriumOceny other = (KryteriumOceny) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", tekst=").append(tekst);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KryteriumOceny.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypKryteriumOceny;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class KryteriumOceny extends GenericDPSObject {
    /**
     * KRYTERIUM_OCENY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * KRYTERIUM_OCENY.TEKST
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tekst;

    /**
     * KRYTERIUM_OCENY.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypKryteriumOceny typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KRYTERIUM_OCENY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KRYTERIUM_OCENY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KRYTERIUM_OCENY.TEKST
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * KRYTERIUM_OCENY.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @return KRYTERIUM_OCENY.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypKryteriumOceny getTyp() {
        return typ;
    }

    /**
     * KRYTERIUM_OCENY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypKryteriumOceny typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KryteriumOceny other = (KryteriumOceny) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", tekst=").append(tekst);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
